---
license: apache-2.0
library_name: transformers
pipeline_tag: text-generation
base_model: Qwen/Qwen2.5-7B
language:
- en
- zh
---



# Xwen-7B-Chat

> [!IMPORTANT]
> If you enjoy our model, please **give it a like on our Hugging Face repo**. Your support means a lot to us. Thank you!

> [!IMPORTANT]
> You can download the **GGUF files of Xwen-7B-Chat** at [xwen-team/Xwen-7B-Chat-i1-GGUF](https://huggingface.co/xwen-team/Xwen-7B-Chat-i1-GGUF) (weighted/imatrix quants) and [xwen-team/Xwen-7B-Chat-GGUF](https://huggingface.co/xwen-team/Xwen-7B-Chat-GGUF) (static quants).

NEWS:
- Big thanks to @mradermacher for helping us build GGUFs for our Xwen-72B-Chat and Xwen-7B-Chat! The GGUF files have accumulated **over 2k downloads in one day** 🚀 Our official GGUF repos: [**xwen-team/Xwen-7B-Chat-i1-GGUF**](https://huggingface.co/xwen-team/Xwen-7B-Chat-i1-GGUF) (weighted/imatrix quants) and [**xwen-team/Xwen-7B-Chat-GGUF**](https://huggingface.co/xwen-team/Xwen-7B-Chat-GGUF) (static quants).



<img src="Xwen-Cartoon.jpg" alt="Xwen-Cartoon" style="zoom:35%;" />

## 1. Introduction


Xwen is a series of open-sourced large language models (currently including **[Xwen-72B-Chat](https://huggingface.co/xwen-team/Xwen-72B-Chat)** and **[Xwen-7B-Chat](https://huggingface.co/xwen-team/Xwen-7B-Chat)**), post-trained from the pre-trained Qwen2.5 models (i.e., [Qwen2.5-72B](https://huggingface.co/Qwen/Qwen2.5-72B) and [Qwen2.5-7B](https://huggingface.co/Qwen/Qwen2.5-7B)) [1].

**🏆 Top-1 chat performance!** To the best of our knowledge, at the time of Xwen models' release (February 1, 2025), **[Xwen-72B-Chat](https://huggingface.co/xwen-team/Xwen-72B-Chat) and [Xwen-7B-Chat](https://huggingface.co/xwen-team/Xwen-7B-Chat) exhibit the best chat performance among open-sourced models below 100B and 10B, respectively**, based on evaluation results from widely-used benchmarks such as Arena-Hard-Auto [2], MT-Bench [3], and AlignBench [4]. Please view details in the [Evaluation Results](https://huggingface.co/xwen-team/Xwen-7B-Chat#3-evaluation-results) part.

**🚀 Xwen technical report is on the way!** During the training of Xwen models, we have accumulated many technical insights and lessons. To promote the democratization of technology, we are in the process of documenting these insights and lessons in a technical report, which will be released as soon as possible.



## 2. Usage

> [!CAUTION]
> For optimal performance, we refrain from fine-tuning the model's identity. Thus, inquiries such as "Who are you" or "Who developed you" may yield random responses that are not necessarily accurate. 

> [!CAUTION]
> This open-source model is provided "as is," without warranties or liabilities, and users assume all risks associated with its use; users are advised to comply with local laws, and the model's outputs do not represent the views or positions of the developers. 

The usage of our Xwen-Chat models is similar to that of the Qwen2.5-Instruct models, with the tokenizer and chat template being identical to those of the Qwen2.5-Instruct models.

Here we provide a python script to demonstrate how to deploy our Xwen models to generate reponses:


```python
from transformers import AutoModelForCausalLM, AutoTokenizer

model_name = "xwen-team/Xwen-7B-Chat"   # Or "xwen-team/Xwen-72B-Chat" if you want to use the 72B model

model = AutoModelForCausalLM.from_pretrained(
    model_name,
    torch_dtype="auto",
    device_map="auto"
)
tokenizer = AutoTokenizer.from_pretrained(model_name)

prompt = "Give me a short introduction to large language models."
messages = [
    {"role": "system", "content": "You are Xwen, created by Xwen Team. You are a helpful assistant."},   # This system prompt is not necessary, and you can put it as an empty string.
    {"role": "user", "content": prompt}
]
text = tokenizer.apply_chat_template(
    messages,
    tokenize=False,
    add_generation_prompt=True
)
model_inputs = tokenizer([text], return_tensors="pt").to(model.device)

generated_ids = model.generate(
    **model_inputs,
    max_new_tokens=512
)
generated_ids = [
    output_ids[len(input_ids):] for input_ids, output_ids in zip(model_inputs.input_ids, generated_ids)
]

response = tokenizer.batch_decode(generated_ids, skip_special_tokens=True)[0]

print(response)
```

## 3. Evaluation Results

> [!CAUTION]
> Results on other benchmarks will be updated soon! 😊

🔑: Open-sourced

🔒: Proprietary

### 3.1 Arena-Hard-Auto-v0.1

All results below, except those for `Xwen-72B-Chat`, `DeepSeek-V3` and `DeepSeek-R1`, are sourced from [Arena-Hard-Auto](https://github.com/lmarena/arena-hard-auto) (accessed on February 1, 2025).

The results of `DeepSeek-V3` and `DeepSeek-R1` are borrowed from their officially reported results.

#### 3.1.1 No Style Control

**Comparison of Xwen-72B-Chat with other LLMs at a comparable level:**

|                                   | Score                    | 95% CIs     |
| --------------------------------- | ------------------------ | ----------- |
| **Xwen-72B-Chat** 🔑               | **86.1** (Top-1 among 🔑 below 100B) | (-1.5, 1.7) |
| Qwen2.5-72B-Instruct 🔑            | 78.0                     | (-1.8, 1.8) |
| Athene-v2-Chat 🔑                  | 85.0                     | (-1.4, 1.7) |
| DeepSeek-V3 **(671B >> 72B)** 🔑  |  85.5   | N/A  |
| DeepSeek-R1 **(671B >> 72B)** 🔑  |  **92.3** (Top-1 among 🔑)  | N/A  |
| Llama-3.1-Nemotron-70B-Instruct 🔑 | 84.9                     | (-1.7, 1.8) |
| Llama-3.1-405B-Instruct-FP8 🔑     | 69.3                     | (-2.4, 2.2) |
| Claude-3-5-Sonnet-20241022 🔒      | 85.2                     | (-1.4, 1.6) |
| O1-Preview-2024-09-12 🔒           | **92.0** (Top-1 among 🔒) | (-1.2, 1.0) |
| O1-Mini-2024-09-12 🔒              | 90.4                     | (-1.1, 1.3) |
| GPT-4-Turbo-2024-04-09 🔒          | 82.6                     | (-1.8, 1.5) |
| GPT-4-0125-Preview 🔒              | 78.0                     | (-2.1, 2.4) |
| GPT-4o-2024-08-06 🔒               | 77.9                     | (-2.0, 2.1) |
| Yi-Lightning 🔒                    | 81.5                     | (-1.6, 1.6) |
| Yi-Large🔒                         | 63.7                     | (-2.6, 2.4) |
| GLM-4-0520 🔒                      | 63.8                     | (-2.9, 2.8) |


**Comparison of Xwen-7B-Chat with other LLMs at a comparable level:**

|                         | Score    | 95% CIs     |
| ----------------------- | -------- | ----------- |
| **Xwen-7B-Chat** 🔑      | **59.4** | (-2.4, 2.1) |
| Qwen2.5-7B-Instruct 🔑   | 50.4     | (-2.9, 2.5) |
| Gemma-2-27B-IT 🔑        | 57.5     | (-2.1, 2.4) |
| Llama-3.1-8B-Instruct 🔑 | 21.3     | (-1.9, 2.2) |
| Llama-3-8B-Instruct 🔑   | 20.6     | (-2.0, 1.9) |
| Starling-LM-7B-beta 🔑   | 23.0     | (-1.8, 1.8) |
| DeepSeek-R1-Distill-Qwen-7B (only responses) 🔑 | 17.2  | (-1.4, 1.7) |
| DeepSeek-R1-Distill-Qwen-7B (w/ thoughts and responses) 🔑 |  13.6  | (-1.4, 1.8)  |  



#### 3.1.2 Style Control

**Comparison of Xwen-72B-Chat with other LLMs at a comparable level:**

|                                   | Score                    | 95% CIs     |
| --------------------------------- | ------------------------ | ----------- |
| **Xwen-72B-Chat** 🔑               | **72.4** (Top-1 Among 🔑) | (-4.3, 4.1) |
| Qwen2.5-72B-Instruct 🔑            | 63.3                     | (-2.5, 2.3) |
| Athene-v2-Chat 🔑                  | 72.1                     | (-2.5, 2.5) |
| Llama-3.1-Nemotron-70B-Instruct 🔑 | 71.0                     | (-2.8, 3.1) |
| Llama-3.1-405B-Instruct-FP8 🔑     | 67.1                     | (-2.2, 2.8) |
| Claude-3-5-Sonnet-20241022 🔒      | **86.4** (Top-1 Among 🔒) | (-1.3, 1.3) |
| O1-Preview-2024-09-12 🔒           | 81.7                     | (-2.2, 2.1) |
| O1-Mini-2024-09-12 🔒              | 79.3                     | (-2.8, 2.3) |
| GPT-4-Turbo-2024-04-09 🔒          | 74.3                     | (-2.4, 2.4) |
| GPT-4-0125-Preview 🔒              | 73.6                     | (-2.0, 2.0) |
| GPT-4o-2024-08-06 🔒               | 71.1                     | (-2.5, 2.0) |
| Yi-Lightning 🔒                    | 66.9                     | (-3.3, 2.7) |
| Yi-Large-Preview 🔒                | 65.1                     | (-2.5, 2.5) |
| GLM-4-0520 🔒                      | 61.4                     | (-2.6, 2.4) |

**Comparison of Xwen-7B-Chat with other LLMs at a comparable level:**

|                         | Score    | 95% CIs     |
| ----------------------- | -------- | ----------- |
| **Xwen-7B-Chat** 🔑      | **50.3** | (-3.8, 2.8) |
| Qwen2.5-7B-Instruct 🔑   | 46.9     | (-3.1, 2.7) |
| Gemma-2-27B-IT 🔑        | 47.5     | (-2.5, 2.7) |
| Llama-3.1-8B-Instruct 🔑 | 18.3     | (-1.6, 1.6) |
| Llama-3-8B-Instruct 🔑   | 19.8     | (-1.6, 1.9) |
| Starling-LM-7B-beta 🔑   | 26.1     | (-2.6, 2.0) |
| DeepSeek-R1-Distill-Qwen-7B (only responses) 🔑 | 18.5  | (-1.6, 1.8) |
| DeepSeek-R1-Distill-Qwen-7B (w/ thoughts and responses) 🔑 |  11.8  | (-1.6, 1.6)  |  


### 3.2 AlignBench-v1.1

> [!IMPORTANT]
> We replaced the original judge model, `GPT-4-0613`, in AlignBench with the more powerful model, `GPT-4o-0513`. To keep fairness, all the results below are generated by ``GPT-4o-0513``. As a result, the following results may differ from the AlignBench-v1.1 scores reported elsewhere.

**Comparison of Xwen-72B-Chat with other LLMs at a comparable level:**

|                               | Score                    |
| ----------------------------- | ------------------------ |
| **Xwen-72B-Chat** 🔑           | **7.57** (Top-1 Among 🔑) |
| Qwen2.5-72B-Instruct 🔑            | 7.51                     |
| Deepseek V2.5 🔑               | 7.38                     |
| Mistral-Large-Instruct-2407 🔑 | 7.10                     |
| Llama3.1-70B-Instruct 🔑       | 5.81                     |
| Llama-3.1-405B-Instruct-FP8 🔑 | 5.56                     |
| GPT-4o-0513 🔒                 | **7.59** (Top-1 Among 🔒) |
| Claude-3.5-Sonnet-20240620 🔒  | 7.17                     |
| Yi-Lightning 🔒                | 7.54                     |
| Yi-Large-Preview 🔒            | 7.20                     |


**Comparison of Xwen-7B-Chat with other LLMs at a comparable level:**

|                    | Score    |
| ------------------ | -------- |
| **Xwen-7B-Chat** 🔑 | **6.88** |
| Qwen2.5-7B-Chat 🔑  | 6.56     |

### 3.3 MT-Bench

> [!IMPORTANT]
> We replaced the original judge model, `GPT-4`, in MT-Bench with the more powerful model, `GPT-4o-0513`. To keep fairness, all the results below are generated by ``GPT-4o-0513``. As a result, the following results may differ from the MT-Bench scores reported elsewhere.

**Comparison of Xwen-72B-Chat with other LLMs at a comparable level:**

|                               | Score                    |
| ----------------------------- | ------------------------ |
| **Xwen-72B-Chat** 🔑           | **8.64** (Top-1 Among 🔑) |
| Qwen2.5-72B-Instruct 🔑            | 8.62                     |
| Deepseek V2.5 🔑               | 8.43                     |
| Mistral-Large-Instruct-2407 🔑 | 8.53                     |
| Llama3.1-70B-Instruct 🔑       | 8.23                     |
| Llama-3.1-405B-Instruct-FP8 🔑 | 8.36                     |
| GPT-4o-0513 🔒                 | 8.59                     |
| Claude-3.5-Sonnet-20240620 🔒  | 6.96                     |
| Yi-Lightning 🔒                | **8.75** (Top-1 Among 🔒) |
| Yi-Large-Preview 🔒            | 8.32                     |

**Comparison of Xwen-7B-Chat with other LLMs at a comparable level:**

|                    | Score    |
| ------------------ | -------- |
| **Xwen-7B-Chat** 🔑 | **7.98** |
| Qwen2.5-7B-Chat 🔑  | 7.71     |


## References

[1] Yang, An, et al. "Qwen2. 5 technical report." arXiv preprint arXiv:2412.15115 (2024).

[2] Li, Tianle, et al. "From Crowdsourced Data to High-Quality Benchmarks: Arena-Hard and BenchBuilder Pipeline." arXiv preprint arXiv:2406.11939 (2024).

[3] Zheng, Lianmin, et al. "Judging llm-as-a-judge with mt-bench and chatbot arena." Advances in Neural Information Processing Systems 36 (2023).

[4] Liu, Xiao, et al. "Alignbench: Benchmarking chinese alignment of large language models." Proceedings of the 62nd Annual Meeting of the Association for Computational Linguistics (2024).

